instrumenttools.Trumpet
=======================

.. abjad-lineage:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet

.. autoclass:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet
   :noindex:

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.default_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.default_short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.effective_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.interval_of_transposition
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.is_primary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.is_secondary_instrument
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.is_transposing
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.start_component
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.storage_format
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.target_context
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.traditional_pitch_range
   :noindex:

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.all_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.pitch_range
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.primary_clefs
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.short_instrument_name
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.short_instrument_name_markup
   :noindex:

.. autoattribute:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.sounding_pitch_of_fingered_middle_c
   :noindex:

Methods
-------

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.attach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.detach
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.get_default_performer_name
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.get_performer_names
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__call__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__delattr__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__eq__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__ge__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__gt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__hash__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__le__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__lt__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__ne__
   :noindex:

.. automethod:: abjad.tools.instrumenttools.Trumpet.Trumpet.Trumpet.__repr__
   :noindex:
